@@ -185,6 +185,18 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             return None
         return res[isotopomers]
 
+    def _make_legend_labels(
+        self, prefix: str, compound: str, initial_index: int
+    ) -> list[str]:
+        return [
+            f"{prefix}{i}"
+            for i in range(
+                initial_index,
+                self.model.get_compound_number_of_label_positions(compound)
+                + initial_index,
+            )
+        ]
+
     def plot(
         self,
         xlabel: str | None = None,
@@ -261,6 +273,8 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
+        prefix: str = "Pos ",
+        initial_index: int = 0,
         figure_kwargs: Dict[str, Any] | None = None,
         subplot_kwargs: Dict[str, Any] | None = None,
         plot_kwargs: Dict[str, Any] | None = None,
@@ -277,9 +291,12 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         y = self._calculate_label_distribution(compound=compound, relative=relative)
         if x is None or y is None:
             return None, None
+
         return plot(
             plot_args=(x, y),
-            legend=None,
+            legend=self._make_legend_labels(
+                prefix=prefix, compound=compound, initial_index=initial_index
+            ),
             xlabel=xlabel,
             ylabel=ylabel,
             title=title,
@@ -309,6 +326,8 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         figure_title: Optional[str] = None,
         grid: bool = True,
         tight_layout: bool = True,
+        prefix: str = "Pos ",
+        initial_index: int = 0,
         figure_kwargs: Optional[Dict[str, Any]] = None,
         subplot_kwargs: Optional[Dict[str, Any]] = None,
         plot_kwargs: Optional[Dict[str, Any]] = None,
@@ -330,12 +349,9 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             for compound in compounds
         ]
         legend_groups = [
-            [
-                f"Pos {i}"
-                for i in range(
-                    self.model.get_compound_number_of_label_positions(compound=compound)
-                )
-            ]
+            self._make_legend_labels(
+                prefix=prefix, compound=compound, initial_index=initial_index
+            )
             for compound in compounds
         ]
         if ylabels is None and relative:
@@ -376,6 +392,8 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         figure_title: Optional[str] = None,
         grid: bool = True,
         tight_layout: bool = True,
+        prefix: str = "Pos ",
+        initial_index: int = 0,
         figure_kwargs: Optional[Dict[str, Any]] = None,
         subplot_kwargs: Optional[Dict[str, Any]] = None,
         plot_kwargs: Optional[Dict[str, Any]] = None,
@@ -389,22 +407,19 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         time = self.get_time()
         if time is None:
             return None, None
-        base_compounds = self.model.label_compounds
+        compounds = self.model.label_compounds
         plot_groups = [
             (
                 time,
                 self._calculate_label_distribution(compound=compound, relative=relative),
             )
-            for compound in base_compounds
+            for compound in compounds
         ]
         legend_groups = [
-            [
-                f"Pos {i}"
-                for i in range(
-                    self.model.get_compound_number_of_label_positions(compound=compound)
-                )
-            ]
-            for compound in base_compounds
+            self._make_legend_labels(
+                prefix=prefix, compound=compound, initial_index=initial_index
+            )
+            for compound in compounds
         ]
         if ylabels is None and relative:
             ylabels = "Relative concentration"
